"""
    utils.py

# Description
Utilities for the l2logger/l2metrics component of the DCCR project.
"""

# -----------------------------------------------------------------------------
# DEPENDENCIES
# -----------------------------------------------------------------------------

from pathlib import Path
import torch
import random
import numpy as np

from types import SimpleNamespace

# -----------------------------------------------------------------------------
# FUNCTIONS
# -----------------------------------------------------------------------------


# # Point to the top of the project relative to this script
def projectdir(*args):
    return str(Path.cwd().joinpath("..", "..", "..", *args).resolve())


def print_allocated_memory():
    print("{:.2f} GB".format(torch.cuda.memory_allocated() / 1024 ** 3))


def scratchdir(name):
    dataset_root = Path("/lustre", "scratch", "sap625", "data", name)
    dataset_root.mkdir(parents=True, exist_ok=True)
    return dataset_root


def set_seed(seed):
    if seed is None:
        return
    torch.manual_seed(seed)
    torch.cuda.manual_seed(seed)
    np.random.seed(seed)
    random.seed(seed)
    if torch.cuda.is_available():
        torch.backends.cudnn.deterministic = True
        torch.backends.cudnn.enabled = True
        torch.backends.cudnn.benchmark = False


def create_default_args(args_dict, additional_args=None):
    args = SimpleNamespace()
    for k, v in args_dict.items():
        args.__dict__[k] = v
    if additional_args is not None:
        for k, v in additional_args.items():
            args.__dict__[k] = v
    return args
